# AzQueueManager-RSS Extension
RSS Extension  for [AZ Queue Manager](https://pypi.org/project/azqueuemanager/)

|||
---|---
|Transform | RSSTransform | 
|transform_in | ✅ |
|transform_preview | 🚫 |
|transform_out | 🚫 |


to install:
```bash
pip install azqueuemanager-rss
```
